@@ -6,7 +6,7 @@ import (
 	"errors"
 	"fmt"
 	"io/fs"
-	"path/filepath"
+	"path"
 
 	"github.com/lima-vm/lima/pkg/iso9660util"
 
@@ -82,7 +82,7 @@ func ValidateTemplateArgs(args TemplateArgs) error {
 	}
 	for i, m := range args.Mounts {
 		f := m.MountPoint
-		if !filepath.IsAbs(f) {
+		if !path.IsAbs(f) {
 			return fmt.Errorf("field mounts[%d] must be absolute, got %q", i, f)
 		}
 	}
