@@ -63,10 +63,11 @@ type Image struct {
 }
 
 type Mount struct {
-	Location string `yaml:"location" json:"location"` // REQUIRED
-	Writable *bool  `yaml:"writable,omitempty" json:"writable,omitempty"`
-	SSHFS    SSHFS  `yaml:"sshfs,omitempty" json:"sshfs,omitempty"`
-	NineP    NineP  `yaml:"9p,omitempty" json:"9p,omitempty"`
+	Location   string `yaml:"location" json:"location"` // REQUIRED
+	MountPoint string `yaml:"mountPoint,omitempty" json:"mountPoint,omitempty"`
+	Writable   *bool  `yaml:"writable,omitempty" json:"writable,omitempty"`
+	SSHFS      SSHFS  `yaml:"sshfs,omitempty" json:"sshfs,omitempty"`
+	NineP      NineP  `yaml:"9p,omitempty" json:"9p,omitempty"`
 }
 
 type SFTPDriver = string
@@ -95,6 +96,8 @@ type SSH struct {
 	// LoadDotSSHPubKeys loads ~/.ssh/*.pub in addition to $LIMA_HOME/_config/user.pub .
 	LoadDotSSHPubKeys *bool `yaml:"loadDotSSHPubKeys,omitempty" json:"loadDotSSHPubKeys,omitempty"` // default: true
 	ForwardAgent      *bool `yaml:"forwardAgent,omitempty" json:"forwardAgent,omitempty"`           // default: false
+	ForwardX11        *bool `yaml:"forwardX11,omitempty" json:"forwardX11,omitempty"`               // default: false
+	ForwardX11Trusted *bool `yaml:"forwardX11Trusted,omitempty" json:"forwardX11Trusted,omitempty"` // default: false
 }
 
 type Firmware struct {
